window.Gleam.initSearch([{"doc":"cake","title":"cake","content":"# Cake SQL Query Builder for Gleam\n\nCake is a library written in Gleam to compose SQL queries targeting SQL dialects PostgreSQL, SQLite, MariaDB and MySQL.\n\n[![Package\n&lt;a href=&quot;https://github.com/inoas/gleam-cake/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-cake&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![CI](https://github.com/inoas/gleam-cake/workflows/test/badge.svg?branch=main)\nVersion](https://img.shields.io/hexpm/v/cake)](https://hex.pm/packages/cake)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cake/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)\n![JavaScript Compatible](https://img.shields.io/badge/target-javascript-f3e155)\n![Unit tests](https://github.com/github/docs/actions/workflows/test.yml/badge.svg)\n\n## Installation\n\n```shell\ngleam add cake\n```\n\nFurther documentation can be found on [hexdocs.pm/cake](https://hexdocs.pm/cake).\n\n## Code examples\n\nSee Cake&#39;s [tests](https://github.com/inoas/gleam-cake/tree/main/test/cake_test), especially the _Setup_ sections in each test module.\n\nYou may also compare the tests with the [snapshots](https://github.com/inoas/gleam-cake/tree/main/birdie_snapshots) results.\n\n### Demo apps\n\nSee [docs/demo-apps.md](https://github.com/inoas/gleam-cake/blob/main/docs/demo-apps.md#available-demos).\n\n## Usage\n\n- SELECT and decoding -\n  [cake\\_demo\\_select\\_and\\_decode.gleam](https://github.com/inoas/gleam-cake/blob/main/docs/demo-apps/01_demo_select_and_decode/src/cake_demo_select_and_decode.gleam)\n- UNION and decoding -\n  [cake\\_demo\\_union\\_and\\_decode.gleam](https://github.com/inoas/gleam-cake/blob/main/docs/demo-apps/02_demo_union_and_decode/src/cake_demo_union_and_decode.gleam)\n- ... more to come soon!\n&lt;!--\n- INSERT -- TODO v1\n- UPDATE -- TODO v1\n- INSERT ON CONFLICT UPDATE -- TODO v1\n- DELETE -- TODO v1\n- INNER JOIN -- TODO v1\n- LEFT JOIN -- TODO v1\n- literal fragment -- TODO v1\n- prepared fragment -- TODO v1\n--&gt;\n\n### Tips\n\nUse the following aliases to make the library more ergonomic:\n\n```gleam\nimport cake/select as s // SELECT statements\nimport cake/where as w // WHERE clauses\nimport cake/join as j // JOIN clauses\nimport cake/update as u // UPDATE statements\nimport cake/insert as i // INSERT statements\nimport cake/delete as d // DELETE statements\nimport cake/combined as c // For combined queries such as UNION\nimport cake/fragment as f // For arbitrary SQL code including functions\n```\n\n## Library Design\n\n### Scope\n\nThis is an SQL query building library, thus it is not concerned about executing queries or decoding return values from queries, but merely about being a flexible and powerful tool to compose and craft SQL read and write queries.\n\n#### Goals\n\n- High degree of flexibility to compose queries:\n  While the focus is on building queries there is also support for replacing\n  or removing parts of queries.\n- General support on these 4 large RDMS: PostgreSQL, SQLite, MariaDB and MySQL.\n- Not being tied to any specific dialect or dialect adapter library.\n- Documentation should be comprehensive.\n- It should be easy to use with existing gleam dialect adapters such as:\n  - [gleam_pgo](https://hex.pm/packages/gleam_pgo)\n  - [sqlight](https://hex.pm/packages/sqlight)\n  - [gmysql](https://hex.pm/packages/gmysql)\n- Allow to define custom SQL fragments while still being safe\n  from SQL injections by using prepared statements.\n\n#### Non-goals\n\n- Prohibition of invalid SQL queries: You can still craft invalid queries at\n  any time, for example:\n  - Omitting certain parts of queries required for them to run, such as\n    not specifying a table name\n  - Comparing values incompatible by SQL type\n- Backporting many features between different RDMBS. For example, while Cake\n  supports `RETURNING` on PostgreSQL and SQLite, it does not support it on\n  MariaDB or MySQL.\n- No automagic optimization: This library is not here to replace SQL knowledge,\n  but to allow crafting and combining SQL queries in a flexible and type safe\n  way. It might however work as a gateway to obtain SQL knowlege because\n  the typed buidler functions help to some degree in understanding how SQL\n  queries can be crafted.\n\n### Tested targets\n\n- Sqlite3 as part of [ubuntu:latest (Docker)](https://hub.docker.com/_/ubuntu)\n- [postgres:latest (Docker)](https://hub.docker.com/_/postgres)\n- [mariadb:latest (Docker)](https://hub.docker.com/_/mariadb)\n- [mysql:latest (Docker)](https://hub.docker.com/_/mysql)\n\nThe tests run on Erlang but are generally target agnostic:\nWhile the primary use case is to run queries on servers, this library runs on any Gleam target and for example in conjunction with [sqlite3 WASM/JS](https://sqlite.org/wasm) you may run queries composed with this library in browsers.\n\n## Development\n\n### Run test suite locally\n\n```shell\nbin/docker/attached\n# wait a few seconds until everything is ready\n# if you run gleam test too early, it will crash\ngleam test\n# or instead of gleam test, run:\n# gleam test -- --glacier\n# ...for incremental testing\n```\n\n### Helper commands\n\n```shell\nbin/docker/attached\nbin/docker/detached\nbin/docker/down\n\nbin/test\nbin/glacier\n\nbin/birdie/interactive-review\nbin/birdie/accept-all\nbin/birdie/reject-all\n```\n\n## Library naming\n\nThe best part of working with CakePHP 3+ used to be its Query Builder. This library is inspired by that and thus the name.\n\nThank you [@lorenzo](https://github.com/lorenzo) and [@markstory](https://github.com/markstory) for creating and maintaining CakePHP and its awesome query builder over the years.\n","url":"index.html"},{"doc":"cake","title":"cake","content":"# Changelog\n\n## 0.9.2 - 2024-07-07\n\n- Added more more applications.\n- Added tests and snapshots for upserts.\n\n## 0.9.1 - 2024-07-05\n\n- Fix test suite.\n\n## 0.9.0 - 2024-07-05\n\n- Improved documentation.\n- Added demo app abstraction.\n- Added first runnable demo for `SELECT` and decode.\n\n## 0.8.0 - 2024-07-03\n\n- Flattened the query interface/DSL modules into the base namespace of `cake/`.\n- Moved some modules only used internally into `cake/internal/` namespace.\n- Fixed and improved test suite for `DELETE` statements.\n- Improved general documentation.\n\n## 0.7.0 - 2024-07-01\n\n- Improved builder flexibility for inserts and updates.\n- Added documentation for the `insert`, `update` and `delete` interface modules.\n- Improved tests for `UPDATE`.\n- Renamed `select.groups_by` to `select.group_bys`.\n- Fixed bugs when updating with sub-queries, where specifying a sub_query\n  while setting update columns to vales would remove all other settings.\n\n## 0.6.0 - 2024-06-27\n\n- Added MySQL independent of MariaDB as first class supported.\n\n## 0.5.0 - 2024-06-26\n\n- Fixed github CI and docker compose testing against Postgres and MariaDB.\n- Locally you should be able to install docker and then just run:\n  `bin/docker/detached/` and then `gleam test`.\n- Relaxed licence from AGPL 3.0 to Mozilla Public License 2.0 (MPL-2.0).\n\n## 0.4.0 - 2024-06-22\n\n- Added support for deletes and interface modules\n  for `insert`, `update`, `delete` ontop of the existing\n  `select` and `combined` interface modules.\n- Added support for MariaDB and MySQL.\n- Removed the hard dependency on any RDMBS specific\n  library. These are now only required when developing and testing\n  this library, but when running you can chose any of the following adapters:\n  - `gleam_pgo`\n  - `sqlight`\n  - `gmysql`\n\n## 0.3.0 - 2024-06-19\n\n- Fixes around inserts, updates, moved a lot of deps to dev deps.\n\n## 0.2.0 - 2024-06-19\n\n- A lot of polishing, support for inserts and updates.\n\n## 0.1.0 - 2024-05-22\n\n- First preview / demo.\n","url":"changelog.html"},{"doc":"cake","title":"main","content":"pub fn main() -&gt; Nil\n As a library *Cake* cannot be invoked directly in a meaningful way.\n\nSynonyms:\ncake.main\ncake main","url":"cake.html#main"},{"doc":"cake","title":"cake","content":" *Cake* is an SQL query building library for RDBMS:\n\n - PostgreSQL\n - SQLite\n - MariaDB\n - MySQL\n\n For examples see the tests.\n","url":"cake.html"},{"doc":"cake/combined","title":"Direction","content":"pub type Direction {\n  Asc\n  Desc\n}\n Defines the direction of an `OrderBy`.\n\nAsc\n\n\nDesc\n\n\nSynonyms:\ncake/combined.Direction\ncake/combined Direction","url":"cake/combined.html#Direction"},{"doc":"cake/combined","title":"comment","content":"pub fn comment(\n  query qry: Combined,\n  comment cmmnt: String,\n) -&gt; Combined\n Appends a `Comment` to the `Combined` query.\n\nSynonyms:\ncake/combined.comment\ncake/combined comment","url":"cake/combined.html#comment"},{"doc":"cake/combined","title":"epilog","content":"pub fn epilog(\n  query qry: Combined,\n  epilog eplg: String,\n) -&gt; Combined\n Appends an `Epilog` to the `Combined` query.\n\nSynonyms:\ncake/combined.epilog\ncake/combined epilog","url":"cake/combined.html#epilog"},{"doc":"cake/combined","title":"except","content":"pub fn except(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates an `EXCEPT` query out of two queries as a `Combined` query.\n\nSynonyms:\ncake/combined.except\ncake/combined except","url":"cake/combined.html#except"},{"doc":"cake/combined","title":"except_all","content":"pub fn except_all(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates an `EXCEPT ALL` query out of two queries as a `Combined` query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/combined.except_all\ncake/combined except_all","url":"cake/combined.html#except_all"},{"doc":"cake/combined","title":"except_all_many","content":"pub fn except_all_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates an `EXCEPT ALL` query out of two or more queries as a `Combined`\n query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/combined.except_all_many\ncake/combined except_all_many","url":"cake/combined.html#except_all_many"},{"doc":"cake/combined","title":"except_many","content":"pub fn except_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates an `EXCEPT` query out of two or more queries as a `Combined` query.\n\nSynonyms:\ncake/combined.except_many\ncake/combined except_many","url":"cake/combined.html#except_many"},{"doc":"cake/combined","title":"get_comment","content":"pub fn get_comment(query qry: Combined) -&gt; Comment\n Gets the `Comment` from the `Combined` query.\n\nSynonyms:\ncake/combined.get_comment\ncake/combined get_comment","url":"cake/combined.html#get_comment"},{"doc":"cake/combined","title":"get_epilog","content":"pub fn get_epilog(query qry: Combined) -&gt; Epilog\n Gets the `Epilog` from the `Combined` query.\n\nSynonyms:\ncake/combined.get_epilog\ncake/combined get_epilog","url":"cake/combined.html#get_epilog"},{"doc":"cake/combined","title":"get_limit","content":"pub fn get_limit(query qry: Combined) -&gt; Limit\n Gets `Limit` in the `Combined` query.\n\nSynonyms:\ncake/combined.get_limit\ncake/combined get_limit","url":"cake/combined.html#get_limit"},{"doc":"cake/combined","title":"get_offset","content":"pub fn get_offset(query qry: Combined) -&gt; Offset\n Gets `Offset` in the `Combined` query.\n\nSynonyms:\ncake/combined.get_offset\ncake/combined get_offset","url":"cake/combined.html#get_offset"},{"doc":"cake/combined","title":"get_order_by","content":"pub fn get_order_by(query qry: Combined) -&gt; OrderBy\n Gets the `OrderBy` from the `Combined` query.\n\nSynonyms:\ncake/combined.get_order_by\ncake/combined get_order_by","url":"cake/combined.html#get_order_by"},{"doc":"cake/combined","title":"get_queries","content":"pub fn get_queries(combined_query qry: Combined) -&gt; List(Select)\n Gets the queries from a `Combined` query.\n\nSynonyms:\ncake/combined.get_queries\ncake/combined get_queries","url":"cake/combined.html#get_queries"},{"doc":"cake/combined","title":"intersect","content":"pub fn intersect(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates an `INTERSECT` query out of two queries as a `Combined` query.\n\nSynonyms:\ncake/combined.intersect\ncake/combined intersect","url":"cake/combined.html#intersect"},{"doc":"cake/combined","title":"intersect_all","content":"pub fn intersect_all(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates an `INTERSECT ALL` query out of two queries as a `Combined` query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/combined.intersect_all\ncake/combined intersect_all","url":"cake/combined.html#intersect_all"},{"doc":"cake/combined","title":"intersect_all_many","content":"pub fn intersect_all_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates an `INTERSECT ALL` query out of two or more queries as a `Combined`\n query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/combined.intersect_all_many\ncake/combined intersect_all_many","url":"cake/combined.html#intersect_all_many"},{"doc":"cake/combined","title":"intersect_many","content":"pub fn intersect_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates an `INTERSECT` query out of two or more queries as a `Combined`\n query.\n\nSynonyms:\ncake/combined.intersect_many\ncake/combined intersect_many","url":"cake/combined.html#intersect_many"},{"doc":"cake/combined","title":"limit","content":"pub fn limit(query qry: Combined, limit lmt: Int) -&gt; Combined\n Sets a `Limit` in the `Combined` query.\n\nSynonyms:\ncake/combined.limit\ncake/combined limit","url":"cake/combined.html#limit"},{"doc":"cake/combined","title":"no_comment","content":"pub fn no_comment(query qry: Combined) -&gt; Combined\n Removes the `Comment` from the `Combined` query.\n\nSynonyms:\ncake/combined.no_comment\ncake/combined no_comment","url":"cake/combined.html#no_comment"},{"doc":"cake/combined","title":"no_epilog","content":"pub fn no_epilog(query qry: Combined) -&gt; Combined\n Removes the `Epilog` from the `Combined` query.\n\nSynonyms:\ncake/combined.no_epilog\ncake/combined no_epilog","url":"cake/combined.html#no_epilog"},{"doc":"cake/combined","title":"no_limit","content":"pub fn no_limit(query qry: Combined) -&gt; Combined\n Removes `Limit` from the `Combined` query.\n\nSynonyms:\ncake/combined.no_limit\ncake/combined no_limit","url":"cake/combined.html#no_limit"},{"doc":"cake/combined","title":"no_offset","content":"pub fn no_offset(query qry: Combined) -&gt; Combined\n Removes `Offset` from the `Combined` query.\n\nSynonyms:\ncake/combined.no_offset\ncake/combined no_offset","url":"cake/combined.html#no_offset"},{"doc":"cake/combined","title":"no_order_by","content":"pub fn no_order_by(query qry: Combined) -&gt; Combined\n Removes the `OrderBy` from the `Combined` query.\n\nSynonyms:\ncake/combined.no_order_by\ncake/combined no_order_by","url":"cake/combined.html#no_order_by"},{"doc":"cake/combined","title":"offset","content":"pub fn offset(query qry: Combined, offst offst: Int) -&gt; Combined\n Sets an `Offset` in the `Combined` query.\n\nSynonyms:\ncake/combined.offset\ncake/combined offset","url":"cake/combined.html#offset"},{"doc":"cake/combined","title":"order_by","content":"pub fn order_by(\n  query qry: Combined,\n  by ordb: String,\n  direction dir: Direction,\n) -&gt; Combined\n Creates or appends an `OrderBy` a column with a direction.\n\n The direction can either `ASC` or `DESC`.\n\nSynonyms:\ncake/combined.order_by\ncake/combined order_by","url":"cake/combined.html#order_by"},{"doc":"cake/combined","title":"order_by_asc","content":"pub fn order_by_asc(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends an ascending `OrderBy`.\n\nSynonyms:\ncake/combined.order_by_asc\ncake/combined order_by_asc","url":"cake/combined.html#order_by_asc"},{"doc":"cake/combined","title":"order_by_asc_nulls_first","content":"pub fn order_by_asc_nulls_first(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends an ascending `OrderBy` with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/combined.order_by_asc_nulls_first\ncake/combined order_by_asc_nulls_first","url":"cake/combined.html#order_by_asc_nulls_first"},{"doc":"cake/combined","title":"order_by_asc_nulls_last","content":"pub fn order_by_asc_nulls_last(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends an ascending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/combined.order_by_asc_nulls_last\ncake/combined order_by_asc_nulls_last","url":"cake/combined.html#order_by_asc_nulls_last"},{"doc":"cake/combined","title":"order_by_desc","content":"pub fn order_by_desc(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends a descending `OrderBy`.\n\nSynonyms:\ncake/combined.order_by_desc\ncake/combined order_by_desc","url":"cake/combined.html#order_by_desc"},{"doc":"cake/combined","title":"order_by_desc_nulls_first","content":"pub fn order_by_desc_nulls_first(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends a descending order with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/combined.order_by_desc_nulls_first\ncake/combined order_by_desc_nulls_first","url":"cake/combined.html#order_by_desc_nulls_first"},{"doc":"cake/combined","title":"order_by_desc_nulls_last","content":"pub fn order_by_desc_nulls_last(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Creates or appends a descending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/combined.order_by_desc_nulls_last\ncake/combined order_by_desc_nulls_last","url":"cake/combined.html#order_by_desc_nulls_last"},{"doc":"cake/combined","title":"replace_order_by","content":"pub fn replace_order_by(\n  query qry: Combined,\n  by ordb: String,\n  direction dir: Direction,\n) -&gt; Combined\n Replaces the `OrderBy` a column with a direction.\n\nSynonyms:\ncake/combined.replace_order_by\ncake/combined replace_order_by","url":"cake/combined.html#replace_order_by"},{"doc":"cake/combined","title":"replace_order_by_asc","content":"pub fn replace_order_by_asc(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single ascending `OrderBy`.\n\nSynonyms:\ncake/combined.replace_order_by_asc\ncake/combined replace_order_by_asc","url":"cake/combined.html#replace_order_by_asc"},{"doc":"cake/combined","title":"replace_order_by_asc_nulls_first","content":"pub fn replace_order_by_asc_nulls_first(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single ascending `OrderBy` with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/combined.replace_order_by_asc_nulls_first\ncake/combined replace_order_by_asc_nulls_first","url":"cake/combined.html#replace_order_by_asc_nulls_first"},{"doc":"cake/combined","title":"replace_order_by_asc_nulls_last","content":"pub fn replace_order_by_asc_nulls_last(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single ascending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/combined.replace_order_by_asc_nulls_last\ncake/combined replace_order_by_asc_nulls_last","url":"cake/combined.html#replace_order_by_asc_nulls_last"},{"doc":"cake/combined","title":"replace_order_by_desc","content":"pub fn replace_order_by_desc(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single descending order.\n\nSynonyms:\ncake/combined.replace_order_by_desc\ncake/combined replace_order_by_desc","url":"cake/combined.html#replace_order_by_desc"},{"doc":"cake/combined","title":"replace_order_by_desc_nulls_first","content":"pub fn replace_order_by_desc_nulls_first(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single descending order with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/combined.replace_order_by_desc_nulls_first\ncake/combined replace_order_by_desc_nulls_first","url":"cake/combined.html#replace_order_by_desc_nulls_first"},{"doc":"cake/combined","title":"replace_order_by_desc_nulls_last","content":"pub fn replace_order_by_desc_nulls_last(\n  query qry: Combined,\n  by ordb: String,\n) -&gt; Combined\n Replaces the `OrderBy` a single descending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/combined.replace_order_by_desc_nulls_last\ncake/combined replace_order_by_desc_nulls_last","url":"cake/combined.html#replace_order_by_desc_nulls_last"},{"doc":"cake/combined","title":"to_query","content":"pub fn to_query(combined_query qry: Combined) -&gt; Query\n Creates a `Query` from a `Combined` query.\n\nSynonyms:\ncake/combined.to_query\ncake/combined to_query","url":"cake/combined.html#to_query"},{"doc":"cake/combined","title":"union","content":"pub fn union(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates a `UNION` query out of two queries as a `Combined` query.\n\nSynonyms:\ncake/combined.union\ncake/combined union","url":"cake/combined.html#union"},{"doc":"cake/combined","title":"union_all","content":"pub fn union_all(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n) -&gt; Combined\n Creates a `UNION ALL` query out of two queries as a `Combined` query.\n\nSynonyms:\ncake/combined.union_all\ncake/combined union_all","url":"cake/combined.html#union_all"},{"doc":"cake/combined","title":"union_all_many","content":"pub fn union_all_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates a `UNION ALL` query out of two or more queries as a `Combined`\n query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/combined.union_all_many\ncake/combined union_all_many","url":"cake/combined.html#union_all_many"},{"doc":"cake/combined","title":"union_many","content":"pub fn union_many(\n  query_a qry_a: Select,\n  query_b qry_b: Select,\n  more_queries mr_qrys: List(Select),\n) -&gt; Combined\n Creates a `UNION` query out of two or more queries as a `Combined` query.\n\nSynonyms:\ncake/combined.union_many\ncake/combined union_many","url":"cake/combined.html#union_many"},{"doc":"cake/combined","title":"cake/combined","content":" A DSL to build combined queries, such as:\n\n - `UNION`\n - `UNION ALL`\n - `EXCEPT`\n - `EXCEPT ALL`\n - `INTERSECT`\n - `INTERSECT ALL`\n\n ## Compatibility\n\n - SQLite does not support `EXCEPT ALL` and `INTERSECT ALL`.\n","url":"cake/combined.html"},{"doc":"cake/delete","title":"comment","content":"pub fn comment(\n  query qry: Delete(a),\n  comment cmmnt: String,\n) -&gt; Delete(a)\n Specify a comment for the `Delete` query.\n\nSynonyms:\ncake/delete.comment\ncake/delete comment","url":"cake/delete.html#comment"},{"doc":"cake/delete","title":"epilog","content":"pub fn epilog(\n  query qry: Delete(a),\n  epilog eplg: String,\n) -&gt; Delete(a)\n Specify an epilog for the `Delete` query.\n\nSynonyms:\ncake/delete.epilog\ncake/delete epilog","url":"cake/delete.html#epilog"},{"doc":"cake/delete","title":"get_comment","content":"pub fn get_comment(query qry: Delete(a)) -&gt; Comment\n Get the comment from an `Delete` query.\n\nSynonyms:\ncake/delete.get_comment\ncake/delete get_comment","url":"cake/delete.html#get_comment"},{"doc":"cake/delete","title":"get_epilog","content":"pub fn get_epilog(query qry: Delete(a)) -&gt; Epilog\n Get the epilog from an `Delete` query.\n\nSynonyms:\ncake/delete.get_epilog\ncake/delete get_epilog","url":"cake/delete.html#get_epilog"},{"doc":"cake/delete","title":"get_joins","content":"pub fn get_joins(query qry: Delete(a)) -&gt; Joins\n Gets the `Joins` of the `Delete` query.\n\nSynonyms:\ncake/delete.get_joins\ncake/delete get_joins","url":"cake/delete.html#get_joins"},{"doc":"cake/delete","title":"get_modifier","content":"pub fn get_modifier(query qry: Delete(a)) -&gt; String\n Gets the `DELETE` modifier.\n\nSynonyms:\ncake/delete.get_modifier\ncake/delete get_modifier","url":"cake/delete.html#get_modifier"},{"doc":"cake/delete","title":"get_table","content":"pub fn get_table(query qry: Delete(a)) -&gt; DeleteTable\n Gets the table name of the `Delete` query.\n\nSynonyms:\ncake/delete.get_table\ncake/delete get_table","url":"cake/delete.html#get_table"},{"doc":"cake/delete","title":"get_using","content":"pub fn get_using(query qry: Delete(a)) -&gt; List(From)\n Gets the `USING` clause of the `Delete` query.\n\nSynonyms:\ncake/delete.get_using\ncake/delete get_using","url":"cake/delete.html#get_using"},{"doc":"cake/delete","title":"get_where","content":"pub fn get_where(query qry: Delete(a)) -&gt; Where\n Gets the `Where` of the `Delete` query.\n\nSynonyms:\ncake/delete.get_where\ncake/delete get_where","url":"cake/delete.html#get_where"},{"doc":"cake/delete","title":"join","content":"pub fn join(query qry: Delete(a), join jn: Join) -&gt; Delete(a)\n Adds a `Join` to the `Delete` query.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/delete.join\ncake/delete join","url":"cake/delete.html#join"},{"doc":"cake/delete","title":"joins","content":"pub fn joins(\n  query qry: Delete(a),\n  joins jns: List(Join),\n) -&gt; Delete(a)\n Adds `Join`s to the `Delete` query.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/delete.joins\ncake/delete joins","url":"cake/delete.html#joins"},{"doc":"cake/delete","title":"modifier","content":"pub fn modifier(\n  query qry: Delete(a),\n  modifier mdfr: String,\n) -&gt; Delete(a)\n Sets the `DELETE` modifier.\n\nSynonyms:\ncake/delete.modifier\ncake/delete modifier","url":"cake/delete.html#modifier"},{"doc":"cake/delete","title":"new","content":"pub fn new() -&gt; Delete(a)\n Creates an empty `Delete` query.\n\nSynonyms:\ncake/delete.new\ncake/delete new","url":"cake/delete.html#new"},{"doc":"cake/delete","title":"no_comment","content":"pub fn no_comment(query qry: Delete(a)) -&gt; Delete(a)\n Specify that no comment should be added to the `Delete` query.\n\nSynonyms:\ncake/delete.no_comment\ncake/delete no_comment","url":"cake/delete.html#no_comment"},{"doc":"cake/delete","title":"no_epilog","content":"pub fn no_epilog(query qry: Delete(a)) -&gt; Delete(a)\n Specify that no epilog should be added to the `Delete` query.\n\nSynonyms:\ncake/delete.no_epilog\ncake/delete no_epilog","url":"cake/delete.html#no_epilog"},{"doc":"cake/delete","title":"no_join","content":"pub fn no_join(query qry: Delete(a)) -&gt; Delete(a)\n Removes any `Joins` from the `Delete` query.\n\nSynonyms:\ncake/delete.no_join\ncake/delete no_join","url":"cake/delete.html#no_join"},{"doc":"cake/delete","title":"no_modifier","content":"pub fn no_modifier(query qry: Delete(a)) -&gt; Delete(a)\n Removes the `DELETE` modifier.\n\nSynonyms:\ncake/delete.no_modifier\ncake/delete no_modifier","url":"cake/delete.html#no_modifier"},{"doc":"cake/delete","title":"no_returning","content":"pub fn no_returning(query qry: Delete(a)) -&gt; Delete(a)\n Specify that no columns should be returned after the `Delete` query.\n\nSynonyms:\ncake/delete.no_returning\ncake/delete no_returning","url":"cake/delete.html#no_returning"},{"doc":"cake/delete","title":"no_table","content":"pub fn no_table(query qry: Delete(a)) -&gt; Delete(a)\n Removes the table name from the `Delete` query.\n\nSynonyms:\ncake/delete.no_table\ncake/delete no_table","url":"cake/delete.html#no_table"},{"doc":"cake/delete","title":"no_using","content":"pub fn no_using(query qry: Delete(a)) -&gt; Delete(a)\n Removes the `USING` clause from the `Delete` query.\n\nSynonyms:\ncake/delete.no_using\ncake/delete no_using","url":"cake/delete.html#no_using"},{"doc":"cake/delete","title":"no_where","content":"pub fn no_where(query qry: Delete(a)) -&gt; Delete(a)\n Removes the `Where` from the `Delete` query.\n\nSynonyms:\ncake/delete.no_where\ncake/delete no_where","url":"cake/delete.html#no_where"},{"doc":"cake/delete","title":"or_where","content":"pub fn or_where(\n  query qry: Delete(a),\n  where whr: Where,\n) -&gt; Delete(a)\n Sets an `OrWhere` or appends into an existing `OrWhere`.\n\n - If the outermost `Where` is an `OrWhere`, the new `Where` is appended\n   to the list within `OrWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `OrWhere`.\n\nSynonyms:\ncake/delete.or_where\ncake/delete or_where","url":"cake/delete.html#or_where"},{"doc":"cake/delete","title":"replace_join","content":"pub fn replace_join(\n  query qry: Delete(a),\n  join jn: Join,\n) -&gt; Delete(a)\n Replaces any `Join`s of the `Delete` query with a signle `Join`.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/delete.replace_join\ncake/delete replace_join","url":"cake/delete.html#replace_join"},{"doc":"cake/delete","title":"replace_joins","content":"pub fn replace_joins(\n  query qry: Delete(a),\n  joins jns: List(Join),\n) -&gt; Delete(a)\n Replaces any `Join`s of the `Delete` query with the given `Join`s.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/delete.replace_joins\ncake/delete replace_joins","url":"cake/delete.html#replace_joins"},{"doc":"cake/delete","title":"replace_using_sub_query","content":"pub fn replace_using_sub_query(\n  query qry: Delete(a),\n  sub_query sb_qry: Query,\n  alias als: String,\n) -&gt; Delete(a)\n Replaces the `USING` clause of the `Delete` query with a sub-query.\n\nSynonyms:\ncake/delete.replace_using_sub_query\ncake/delete replace_using_sub_query","url":"cake/delete.html#replace_using_sub_query"},{"doc":"cake/delete","title":"replace_using_table","content":"pub fn replace_using_table(\n  query qry: Delete(a),\n  table tbl: String,\n) -&gt; Delete(a)\n Replaces the `USING` clause of the `Delete` query with a table.\n\nSynonyms:\ncake/delete.replace_using_table\ncake/delete replace_using_table","url":"cake/delete.html#replace_using_table"},{"doc":"cake/delete","title":"replace_where","content":"pub fn replace_where(\n  query qry: Delete(a),\n  where whr: Where,\n) -&gt; Delete(a)\n Replaces the `Where` in the `Delete` query.\n\nSynonyms:\ncake/delete.replace_where\ncake/delete replace_where","url":"cake/delete.html#replace_where"},{"doc":"cake/delete","title":"returning","content":"pub fn returning(\n  query qry: Delete(a),\n  returning rtrn: List(String),\n) -&gt; Delete(a)\n Specify the columns to return after the `Delete` query.\n\nSynonyms:\ncake/delete.returning\ncake/delete returning","url":"cake/delete.html#returning"},{"doc":"cake/delete","title":"table","content":"pub fn table(\n  query qry: Delete(a),\n  table_name tbl_nm: String,\n) -&gt; Delete(a)\n Sets the table name of the `Delete` query, aka the table where\n the rows will be deleted from.\n\nSynonyms:\ncake/delete.table\ncake/delete table","url":"cake/delete.html#table"},{"doc":"cake/delete","title":"to_query","content":"pub fn to_query(delete dlt: Delete(a)) -&gt; WriteQuery(a)\n Creates a `WriteQuery` from a `Delete` query.\n\nSynonyms:\ncake/delete.to_query\ncake/delete to_query","url":"cake/delete.html#to_query"},{"doc":"cake/delete","title":"using_sub_query","content":"pub fn using_sub_query(\n  query qry: Delete(a),\n  sub_query sb_qry: Query,\n  alias als: String,\n) -&gt; Delete(a)\n Adds a `USING` clause to the `Delete` query specifing a sub-query.\n\n The sub-query must be aliased.\n\n If the query already has a `USING` clause, the new `USING` clause\n will be appended to the existing one.\n\n The `USING` clause is used to specify additional tables that are used\n to filter the rows to be deleted.\n\n NOTICE: SQLite does not support `USING`.\n\n NOTICE: MariaDB and MySQL may not support sub-queries in the `USING` clause.\n In such case you may use a sub-query in a `WHERE` clause,  or use a join\n instead.\n\nSynonyms:\ncake/delete.using_sub_query\ncake/delete using_sub_query","url":"cake/delete.html#using_sub_query"},{"doc":"cake/delete","title":"using_table","content":"pub fn using_table(\n  query qry: Delete(a),\n  table tbl: String,\n) -&gt; Delete(a)\n Adds a `USING` clause to the `Delete` query specifing a table.\n\n If the query already has a `USING` clause, the new `USING` clause\n will be appended to the existing one.\n\n The `USING` clause is used to specify additional tables that are used\n to filter the rows to be deleted.\n\n NOTICE: SQLite does not support `USING`.\n\n NOTICE: For MariaDB and MySQL it is mandatory to specify the table specified\n in the `FROM` clause in the `USING` clause, again - e.g. in raw SQL:\n `DELETE * FROM a USING a, b, WHERE a.b_id = b.id;`\n\nSynonyms:\ncake/delete.using_table\ncake/delete using_table","url":"cake/delete.html#using_table"},{"doc":"cake/delete","title":"where","content":"pub fn where(query qry: Delete(a), where whr: Where) -&gt; Delete(a)\n Sets an `AndWhere` or appends into an existing `AndWhere`.\n\n - If the outermost `Where` is an `AndWhere`, the new `Where` is appended\n   to the list within `AndWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `AndWhere`.\n\nSynonyms:\ncake/delete.where\ncake/delete where","url":"cake/delete.html#where"},{"doc":"cake/delete","title":"xor_where","content":"pub fn xor_where(\n  query qry: Delete(a),\n  where whr: Where,\n) -&gt; Delete(a)\n Sets an `XorWhere` or appends into an existing `XorWhere`.\n\n - If the outermost `Where` is an `XorWhere`, the new `Where` is appended\n   to the list within `XorWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `XorWhere`.\n\n NOTICE: This operator does not exist in Postgres or SQLite, and *Cake*\n generates equivalent SQL using `OR` and `AND` and `NOT`.\n This operator exists in MariaDB/MySQL.\n\nSynonyms:\ncake/delete.xor_where\ncake/delete xor_where","url":"cake/delete.html#xor_where"},{"doc":"cake/delete","title":"cake/delete","content":" A DSL to build `DELETE` queries.\n","url":"cake/delete.html"},{"doc":"cake/fragment","title":"placeholder","content":"pub const placeholder: String\n This placeholder must be used when building fragments with parameters.\n\nSynonyms:\ncake/fragment.placeholder\ncake/fragment placeholder","url":"cake/fragment.html#placeholder"},{"doc":"cake/fragment","title":"literal","content":"pub fn literal(string str: String) -&gt; Fragment\n Create a new fragment from a literal string.\n\n ⛔ ⛔ ⛔\n\n WARNING: YOU ARE FORBIDDEN TO INSERT UNCONTROLLED USER INPUT THIS WAY!\n\n ⛔ ⛔ ⛔\n\nSynonyms:\ncake/fragment.literal\ncake/fragment literal","url":"cake/fragment.html#literal"},{"doc":"cake/fragment","title":"prepared","content":"pub fn prepared(\n  string str: String,\n  params prms: List(Param),\n) -&gt; Fragment\n Create a new fragment from a string and a list of parameters.\n\n ⛔ ⛔ ⛔\n\n If you missmatch the number of placeholders with the number of\n parameters, an error will be printed to stderr and the fragment will be\n created with the given parameters:\n\n - If there are too many placeholders, the fragment will be created with the\n   given parameters and the last parameter will be repeated for the remaining\n   placeholders.\n - If there are too many parameters, the fragment will be created with the\n   given parameters and the excess parameters will be ignored.\n\n ⛔ ⛔ ⛔\n\nSynonyms:\ncake/fragment.prepared\ncake/fragment prepared","url":"cake/fragment.html#prepared"},{"doc":"cake/fragment","title":"cake/fragment","content":" Fragments are low level building blocks of queries which allow direct\n manipulation of the query string.\n\n If you want to insert parameters, you are required to use prepared\n fragments, which will be validated against the number of parameters given\n and the parameters are automatically escaped by the RDBMS to prevent SQL\n injections.\n","url":"cake/fragment.html"},{"doc":"cake/having","title":"cake/having","content":" Please use the `where` module instead of this module to specify `HAVING`\n constraints.\n\n `HAVING` and `WHERE` are similar in so far that they both filter data:\n\n - `WHERE` filters input rows before groups and aggregates are computed, and\n   by that controls which rows go into the aggregate computation.\n - `HAVING` filters group rows after groups and aggregates are computed.\n\n Becaue of this difference, `WHERE` can refer to columns that are not part\n of the `GROUP BY` clause, while `HAVING` cannot.\n\n ## Notice\n\n This module is a placeholder until rexporting functions is supported by\n Gleam.\n","url":"cake/having.html"},{"doc":"cake/helper","title":"qualified_identifier","content":"pub fn qualified_identifier(\n  scope scp: String,\n) -&gt; fn(String) -&gt; String\n Returns a callable that creates a qualified identifier\n\nSynonyms:\ncake/helper.qualified_identifier\ncake/helper qualified_identifier","url":"cake/helper.html#qualified_identifier"},{"doc":"cake/helper","title":"cake/helper","content":" Helper functions\n","url":"cake/helper.html"},{"doc":"cake/insert","title":"bool","content":"pub fn bool(value vl: Bool) -&gt; Param\n Create an `InsertValue` from a column `String` and a `Bool` value.\n\nSynonyms:\ncake/insert.bool\ncake/insert bool","url":"cake/insert.html#bool"},{"doc":"cake/insert","title":"columns","content":"pub fn columns(\n  query qry: Insert(a),\n  columns cols: List(String),\n) -&gt; Insert(a)\n Specify the columns to insert into.\n\n NOTICE: You have to specify the columns and keep track if their names are\n correct, as well as their count which must be equal to the count of\n `InsertRows` the caster function returns or is given as source\n          values.\n\nSynonyms:\ncake/insert.columns\ncake/insert columns","url":"cake/insert.html#columns"},{"doc":"cake/insert","title":"comment","content":"pub fn comment(\n  query qry: Insert(a),\n  comment cmmnt: String,\n) -&gt; Insert(a)\n Specify a comment for the `INSERT` query.\n\nSynonyms:\ncake/insert.comment\ncake/insert comment","url":"cake/insert.html#comment"},{"doc":"cake/insert","title":"epilog","content":"pub fn epilog(\n  query qry: Insert(a),\n  epilog eplg: String,\n) -&gt; Insert(a)\n Specify an epilog for the `INSERT` query.\n\nSynonyms:\ncake/insert.epilog\ncake/insert epilog","url":"cake/insert.html#epilog"},{"doc":"cake/insert","title":"float","content":"pub fn float(value vl: Float) -&gt; Param\n Create an `InsertValue` from a column `String` and a `Float` value.\n\nSynonyms:\ncake/insert.float\ncake/insert float","url":"cake/insert.html#float"},{"doc":"cake/insert","title":"from_records","content":"pub fn from_records(\n  table_name tbl_nm: String,\n  columns cols: List(String),\n  records rcrds: List(a),\n  caster cstr: fn(a) -&gt; InsertRow,\n) -&gt; Insert(a)\n Create an `INSERT` query from a list of gleam records.\n\n The `caster` function is used to convert each record into an `InsertRow`.\n\nSynonyms:\ncake/insert.from_records\ncake/insert from_records","url":"cake/insert.html#from_records"},{"doc":"cake/insert","title":"from_values","content":"pub fn from_values(\n  table_name tbl_nm: String,\n  columns cols: List(String),\n  records rcrds: List(InsertRow),\n) -&gt; Insert(a)\n Create an `INSERT` query from a list of `InsertRow`s.\n\nSynonyms:\ncake/insert.from_values\ncake/insert from_values","url":"cake/insert.html#from_values"},{"doc":"cake/insert","title":"get_columns","content":"pub fn get_columns(query qry: Insert(a)) -&gt; InsertColumns\n Get the columns to insert into from an `Insert` query.\n\nSynonyms:\ncake/insert.get_columns\ncake/insert get_columns","url":"cake/insert.html#get_columns"},{"doc":"cake/insert","title":"get_comment","content":"pub fn get_comment(query qry: Insert(a)) -&gt; Comment\n Get the comment from an `INSERT` query.\n\nSynonyms:\ncake/insert.get_comment\ncake/insert get_comment","url":"cake/insert.html#get_comment"},{"doc":"cake/insert","title":"get_epilog","content":"pub fn get_epilog(query qry: Insert(a)) -&gt; Epilog\n Get the epilog from an `INSERT` query.\n\nSynonyms:\ncake/insert.get_epilog\ncake/insert get_epilog","url":"cake/insert.html#get_epilog"},{"doc":"cake/insert","title":"get_modifier","content":"pub fn get_modifier(query qry: Insert(a)) -&gt; String\n Get the modifier from an `Insert` query.\n\nSynonyms:\ncake/insert.get_modifier\ncake/insert get_modifier","url":"cake/insert.html#get_modifier"},{"doc":"cake/insert","title":"get_on_conflict","content":"pub fn get_on_conflict(\n  query qry: Insert(a),\n) -&gt; InsertConflictStrategy(a)\n Get the conflict strategy from an `Insert` query.\n\nSynonyms:\ncake/insert.get_on_conflict\ncake/insert get_on_conflict","url":"cake/insert.html#get_on_conflict"},{"doc":"cake/insert","title":"get_source","content":"pub fn get_source(query qry: Insert(a)) -&gt; InsertSource(a)\n Get the source from an `Insert` query which is either a list of records,\n accompanied by a caster function or a list of `InsertRow`s.\n\nSynonyms:\ncake/insert.get_source\ncake/insert get_source","url":"cake/insert.html#get_source"},{"doc":"cake/insert","title":"get_table","content":"pub fn get_table(query qry: Insert(a)) -&gt; InsertIntoTable\n Get the table name to insert into from an `Insert` query.\n\nSynonyms:\ncake/insert.get_table\ncake/insert get_table","url":"cake/insert.html#get_table"},{"doc":"cake/insert","title":"int","content":"pub fn int(value vl: Int) -&gt; Param\n Create an `InsertValue` from a column `String` and an `Int` value.\n\nSynonyms:\ncake/insert.int\ncake/insert int","url":"cake/insert.html#int"},{"doc":"cake/insert","title":"modifier","content":"pub fn modifier(\n  query qry: Insert(a),\n  modifier mdfr: String,\n) -&gt; Insert(a)\n Specify a modifier for the `INSERT` query.\n\nSynonyms:\ncake/insert.modifier\ncake/insert modifier","url":"cake/insert.html#modifier"},{"doc":"cake/insert","title":"new","content":"pub fn new() -&gt; Insert(a)\n Create an empty `INSERT` query.\n\nSynonyms:\ncake/insert.new\ncake/insert new","url":"cake/insert.html#new"},{"doc":"cake/insert","title":"no_comment","content":"pub fn no_comment(query qry: Insert(a)) -&gt; Insert(a)\n Specify that no comment should be added to the `INSERT` query.\n\nSynonyms:\ncake/insert.no_comment\ncake/insert no_comment","url":"cake/insert.html#no_comment"},{"doc":"cake/insert","title":"no_epilog","content":"pub fn no_epilog(query qry: Insert(a)) -&gt; Insert(a)\n Specify that no epilog should be added to the `INSERT` query.\n\nSynonyms:\ncake/insert.no_epilog\ncake/insert no_epilog","url":"cake/insert.html#no_epilog"},{"doc":"cake/insert","title":"no_modifier","content":"pub fn no_modifier(query qry: Insert(a)) -&gt; Insert(a)\n Specify that no modifier should be used for the given `INSERT` query.\n\nSynonyms:\ncake/insert.no_modifier\ncake/insert no_modifier","url":"cake/insert.html#no_modifier"},{"doc":"cake/insert","title":"no_returning","content":"pub fn no_returning(query qry: Insert(a)) -&gt; Insert(a)\n Specify that no columns should be returned after the `INSERT` query.\n\nSynonyms:\ncake/insert.no_returning\ncake/insert no_returning","url":"cake/insert.html#no_returning"},{"doc":"cake/insert","title":"null","content":"pub fn null() -&gt; Param\n Create a NULL `InsertValue`.\n\nSynonyms:\ncake/insert.null\ncake/insert null","url":"cake/insert.html#null"},{"doc":"cake/insert","title":"on_columns_conflict_ignore","content":"pub fn on_columns_conflict_ignore(\n  query qry: Insert(a),\n  column cols: List(String),\n  where whr: Where,\n) -&gt; Insert(a)\n This specifies that specific conflicts do not result in an error but instead\n are just ignored and not inserted.\n\n Conflict Target: Columns\n\nSynonyms:\ncake/insert.on_columns_conflict_ignore\ncake/insert on_columns_conflict_ignore","url":"cake/insert.html#on_columns_conflict_ignore"},{"doc":"cake/insert","title":"on_columns_conflict_update","content":"pub fn on_columns_conflict_update(\n  query qry: Insert(a),\n  column cols: List(String),\n  where whr: Where,\n  update updt: Update(a),\n) -&gt; Insert(a)\n Inserts or updates on conflict, also called ´.UPSERT´.\n\n Conflict Target: Columns\n\nSynonyms:\ncake/insert.on_columns_conflict_update\ncake/insert on_columns_conflict_update","url":"cake/insert.html#on_columns_conflict_update"},{"doc":"cake/insert","title":"on_conflict_error","content":"pub fn on_conflict_error(query qry: Insert(a)) -&gt; Insert(a)\n This specifies that any conflicts result in the query to fail\n\n This is the default behaviour.\n\nSynonyms:\ncake/insert.on_conflict_error\ncake/insert on_conflict_error","url":"cake/insert.html#on_conflict_error"},{"doc":"cake/insert","title":"on_constraint_conflict_ignore","content":"pub fn on_constraint_conflict_ignore(\n  query qry: Insert(a),\n  constraint cnstrt: String,\n  where whr: Where,\n) -&gt; Insert(a)\n This specifies that specific conflicts do not result in an error but instead\n are just ignored and not inserted.\n\n Conflict Target: Constraint\n\nSynonyms:\ncake/insert.on_constraint_conflict_ignore\ncake/insert on_constraint_conflict_ignore","url":"cake/insert.html#on_constraint_conflict_ignore"},{"doc":"cake/insert","title":"on_constraint_conflict_update","content":"pub fn on_constraint_conflict_update(\n  query qry: Insert(a),\n  constraint cnstrt: String,\n  where whr: Where,\n  update updt: Update(a),\n) -&gt; Insert(a)\n Inserts or updates on conflict, also called ´.UPSERT´.\n\n Conflict Target: Constraint\n\nSynonyms:\ncake/insert.on_constraint_conflict_update\ncake/insert on_constraint_conflict_update","url":"cake/insert.html#on_constraint_conflict_update"},{"doc":"cake/insert","title":"param","content":"pub fn param(column col: String, param prm: Param) -&gt; InsertValue\n Create an `InsertValue` from a column `String` and a `Param`.\nSynonyms:\ncake/insert.param\ncake/insert param","url":"cake/insert.html#param"},{"doc":"cake/insert","title":"returning","content":"pub fn returning(\n  query qry: Insert(a),\n  returning rtrn: List(String),\n) -&gt; Insert(a)\n Specify the columns to return after the `INSERT` query.\n\nSynonyms:\ncake/insert.returning\ncake/insert returning","url":"cake/insert.html#returning"},{"doc":"cake/insert","title":"row","content":"pub fn row(values vls: List(InsertValue)) -&gt; InsertRow\n Create an `InsertRow` from a list of `InsertValue`s.\n\nSynonyms:\ncake/insert.row\ncake/insert row","url":"cake/insert.html#row"},{"doc":"cake/insert","title":"source_records","content":"pub fn source_records(\n  query qry: Insert(a),\n  source rcrds: List(a),\n  caster cstr: fn(a) -&gt; InsertRow,\n) -&gt; Insert(a)\n Specify the source records to insert.\n\nSynonyms:\ncake/insert.source_records\ncake/insert source_records","url":"cake/insert.html#source_records"},{"doc":"cake/insert","title":"source_values","content":"pub fn source_values(\n  query qry: Insert(a),\n  records rcrds: List(InsertRow),\n) -&gt; Insert(a)\n Specify the source values to insert.\n\nSynonyms:\ncake/insert.source_values\ncake/insert source_values","url":"cake/insert.html#source_values"},{"doc":"cake/insert","title":"string","content":"pub fn string(value vl: String) -&gt; Param\n Create an `InsertValue` from a column `String` and a `String` value.\n\nSynonyms:\ncake/insert.string\ncake/insert string","url":"cake/insert.html#string"},{"doc":"cake/insert","title":"table","content":"pub fn table(\n  query qry: Insert(a),\n  table_name tbl_nm: String,\n) -&gt; Insert(a)\n Specify the table to insert into.\n\nSynonyms:\ncake/insert.table\ncake/insert table","url":"cake/insert.html#table"},{"doc":"cake/insert","title":"to_query","content":"pub fn to_query(insert isrt: Insert(a)) -&gt; WriteQuery(a)\n Creates a `WriteQuery` from an `Insert` query.\n\nSynonyms:\ncake/insert.to_query\ncake/insert to_query","url":"cake/insert.html#to_query"},{"doc":"cake/insert","title":"cake/insert","content":" A DSL to build `INSERT` queries.\n","url":"cake/insert.html"},{"doc":"cake/join","title":"cross","content":"pub fn cross(with wth: JoinTarget, alias als: String) -&gt; Join\n Creates a `CROSS JOIN`.\n\n Also called _cartesian product_.\n\nSynonyms:\ncake/join.cross\ncake/join cross","url":"cake/join.html#cross"},{"doc":"cake/join","title":"full","content":"pub fn full(\n  with wth: JoinTarget,\n  on on: Where,\n  alias als: String,\n) -&gt; Join\n Creates a `FULL JOIN`.\n\n Also called `FULL OUTER JOIN`.\n\n _Inclusive_ by default.\n\n Set `on` to `WHERE a.key IS NULL OR b.key IS NULL` to make it _exclusive_.\n\nSynonyms:\ncake/join.full\ncake/join full","url":"cake/join.html#full"},{"doc":"cake/join","title":"inner","content":"pub fn inner(\n  with wth: JoinTarget,\n  on on: Where,\n  alias als: String,\n) -&gt; Join\n Create an `INNER JOIN`.\n\nSynonyms:\ncake/join.inner\ncake/join inner","url":"cake/join.html#inner"},{"doc":"cake/join","title":"left","content":"pub fn left(\n  with wth: JoinTarget,\n  on on: Where,\n  alias als: String,\n) -&gt; Join\n Creates a `LEFT JOIN`.\n\n Also called `LEFT OUTER JOIN`.\n\n _Inclusive_ by default.\n\n Set `on` to `WHERE a.key IS NULL` to make it _exclusive_.\n\nSynonyms:\ncake/join.left\ncake/join left","url":"cake/join.html#left"},{"doc":"cake/join","title":"right","content":"pub fn right(\n  with wth: JoinTarget,\n  on on: Where,\n  alias als: String,\n) -&gt; Join\n Creates a `RIGHT JOIN`.\n\n Also called `RIGHT OUTER JOIN`.\n\n _Inclusive_ by default.\n\n Set `on` to `WHERE b.key IS NULL` to make it _exclusive_.\n\nSynonyms:\ncake/join.right\ncake/join right","url":"cake/join.html#right"},{"doc":"cake/join","title":"sub_query","content":"pub fn sub_query(sub_query sq: Query) -&gt; JoinTarget\n Create a `JOIN` target from a sub-query.\n\nSynonyms:\ncake/join.sub_query\ncake/join sub_query","url":"cake/join.html#sub_query"},{"doc":"cake/join","title":"table","content":"pub fn table(table_name tbl_nm: String) -&gt; JoinTarget\n Create a `JOIN` target from a table name.\n\nSynonyms:\ncake/join.table\ncake/join table","url":"cake/join.html#table"},{"doc":"cake/join","title":"cake/join","content":" Functions to build `JOIN` clauses of SQL queries.\n\n Tables, views and sub-queries can be joined together.\n\n ## Supported join kinds\n\n - `INNER JOIN`\n - `LEFT JOIN`, inclusive, same as `LEFT OUTER JOIN`,\n - `RIGHT JOIN`, inclusive, same as `RIGHT OUTER JOIN`,\n - `FULL JOIN`, inclusive, same as `FULL OUTER JOIN`,\n - `CROSS JOIN`\n\n You can also build following joins using the provided query builder\n functions:\n\n - `SELF JOIN`: Use the same table, view, or sub-query with a different\n    alias.\n - `EXCLUSIVE LEFT JOIN`: `WHERE b.key IS NULL`\n - `EXCLUSIVE RIGHT JOIN`: `WHERE a.key IS NULL`\n - `EXCLUSIVE FULL JOIN`: `WHERE a.key IS NULL OR b.key IS NULL`\n","url":"cake/join.html"},{"doc":"cake/select","title":"Direction","content":"pub type Direction {\n  Asc\n  Desc\n}\n Defines the direction of an `OrderBy`.\n\nAsc\n\n\nDesc\n\n\nSynonyms:\ncake/select.Direction\ncake/select Direction","url":"cake/select.html#Direction"},{"doc":"cake/select","title":"alias","content":"pub fn alias(\n  value vl: SelectValue,\n  alias als: String,\n) -&gt; SelectValue\n Creates an alias off a `String`.\n\nSynonyms:\ncake/select.alias\ncake/select alias","url":"cake/select.html#alias"},{"doc":"cake/select","title":"all","content":"pub fn all(query qry: Select) -&gt; Select\n Sets the kind of the `Select` query to\n return duplicates which is the default.\n\nSynonyms:\ncake/select.all\ncake/select all","url":"cake/select.html#all"},{"doc":"cake/select","title":"bool","content":"pub fn bool(value vl: Bool) -&gt; SelectValue\n Creates a boolean `Param` off a `Bool`.\n\nSynonyms:\ncake/select.bool\ncake/select bool","url":"cake/select.html#bool"},{"doc":"cake/select","title":"col","content":"pub fn col(name nm: String) -&gt; SelectValue\n Creates a column identifier off a `String`.\n\nSynonyms:\ncake/select.col\ncake/select col","url":"cake/select.html#col"},{"doc":"cake/select","title":"comment","content":"pub fn comment(\n  query qry: Select,\n  comment cmmnt: String,\n) -&gt; Select\n Appends a `Comment` to the `Select` query.\n\nSynonyms:\ncake/select.comment\ncake/select comment","url":"cake/select.html#comment"},{"doc":"cake/select","title":"distinct","content":"pub fn distinct(query qry: Select) -&gt; Select\n Sets the kind of the `Select` query to\n return distinct rows only.\n\nSynonyms:\ncake/select.distinct\ncake/select distinct","url":"cake/select.html#distinct"},{"doc":"cake/select","title":"epilog","content":"pub fn epilog(query qry: Select, epilog eplg: String) -&gt; Select\n Appends an `Epilog` to the `Select` query.\n\nSynonyms:\ncake/select.epilog\ncake/select epilog","url":"cake/select.html#epilog"},{"doc":"cake/select","title":"float","content":"pub fn float(value vl: Float) -&gt; SelectValue\n Creates a float `Param` off a `Float`.\n\nSynonyms:\ncake/select.float\ncake/select float","url":"cake/select.html#float"},{"doc":"cake/select","title":"fragment","content":"pub fn fragment(fragment frgmt: Fragment) -&gt; SelectValue\n Creates a `SelectFragment` off a `Fragment`.\nSynonyms:\ncake/select.fragment\ncake/select fragment","url":"cake/select.html#fragment"},{"doc":"cake/select","title":"from_sub_query","content":"pub fn from_sub_query(\n  query qry: Select,\n  sub_query sb_qry: Query,\n  alias als: String,\n) -&gt; Select\n Sets the `FROM` clause of the `Select` query to an aliased sub-query.\n\nSynonyms:\ncake/select.from_sub_query\ncake/select from_sub_query","url":"cake/select.html#from_sub_query"},{"doc":"cake/select","title":"from_table","content":"pub fn from_table(\n  query qry: Select,\n  name tbl_nm: String,\n) -&gt; Select\n Sets the `FROM` clause of the `Select` query to a table name.\n\nSynonyms:\ncake/select.from_table\ncake/select from_table","url":"cake/select.html#from_table"},{"doc":"cake/select","title":"get_comment","content":"pub fn get_comment(query qry: Select) -&gt; Comment\n Gets the `Comment` from the `Select` query.\n\nSynonyms:\ncake/select.get_comment\ncake/select get_comment","url":"cake/select.html#get_comment"},{"doc":"cake/select","title":"get_epilog","content":"pub fn get_epilog(query qry: Select) -&gt; Epilog\n Gets the `Epilog` from the `Select` query.\n\nSynonyms:\ncake/select.get_epilog\ncake/select get_epilog","url":"cake/select.html#get_epilog"},{"doc":"cake/select","title":"get_from","content":"pub fn get_from(query qry: Select) -&gt; From\n Gets the `FROM` clause of the `Select` query.\n\nSynonyms:\ncake/select.get_from\ncake/select get_from","url":"cake/select.html#get_from"},{"doc":"cake/select","title":"get_group_by","content":"pub fn get_group_by(query qry: Select) -&gt; GroupBy\n Gets `GroupBy` in the `Select` query.\n\nSynonyms:\ncake/select.get_group_by\ncake/select get_group_by","url":"cake/select.html#get_group_by"},{"doc":"cake/select","title":"get_having","content":"pub fn get_having(query qry: Select) -&gt; Where\n Gets`HAVING` in the `Select` query.\n\n See function `having` on details why this returns a `Where`.\n\nSynonyms:\ncake/select.get_having\ncake/select get_having","url":"cake/select.html#get_having"},{"doc":"cake/select","title":"get_joins","content":"pub fn get_joins(query qry: Select) -&gt; Joins\n Gets the `Joins` of the `Select` query.\n\nSynonyms:\ncake/select.get_joins\ncake/select get_joins","url":"cake/select.html#get_joins"},{"doc":"cake/select","title":"get_kind","content":"pub fn get_kind(\n  query qry: Select,\n  kind knd: SelectKind,\n) -&gt; Select\n Gets the kind of the `Select` query.\n\nSynonyms:\ncake/select.get_kind\ncake/select get_kind","url":"cake/select.html#get_kind"},{"doc":"cake/select","title":"get_limit","content":"pub fn get_limit(query qry: Select) -&gt; Limit\n Gets `Limit` in the `Select` query.\n\nSynonyms:\ncake/select.get_limit\ncake/select get_limit","url":"cake/select.html#get_limit"},{"doc":"cake/select","title":"get_offset","content":"pub fn get_offset(query qry: Select) -&gt; Offset\n Gets `Offset` in the `Select` query.\n\nSynonyms:\ncake/select.get_offset\ncake/select get_offset","url":"cake/select.html#get_offset"},{"doc":"cake/select","title":"get_order_by","content":"pub fn get_order_by(query qry: Select) -&gt; OrderBy\n Gets the `OrderBy` from the `Select` query.\n\nSynonyms:\ncake/select.get_order_by\ncake/select get_order_by","url":"cake/select.html#get_order_by"},{"doc":"cake/select","title":"get_select","content":"pub fn get_select(query qry: Select) -&gt; Selects\n Gets the `SelectValue`s of the `Select` query.\n\nSynonyms:\ncake/select.get_select\ncake/select get_select","url":"cake/select.html#get_select"},{"doc":"cake/select","title":"get_where","content":"pub fn get_where(query qry: Select) -&gt; Where\n Gets the `Where` of the `Select` query.\n\nSynonyms:\ncake/select.get_where\ncake/select get_where","url":"cake/select.html#get_where"},{"doc":"cake/select","title":"group_by","content":"pub fn group_by(\n  query qry: Select,\n  group_by grpb: String,\n) -&gt; Select\n Sets or appends `GroupBy` a single into an existing `GroupBy`.\n\nSynonyms:\ncake/select.group_by\ncake/select group_by","url":"cake/select.html#group_by"},{"doc":"cake/select","title":"group_bys","content":"pub fn group_bys(\n  query qry: Select,\n  group_bys grpbs: List(String),\n) -&gt; Select\n Sets or appends a list of `GroupBy` into an existing `GroupBy`.\n\nSynonyms:\ncake/select.group_bys\ncake/select group_bys","url":"cake/select.html#group_bys"},{"doc":"cake/select","title":"having","content":"pub fn having(query qry: Select, having whr: Where) -&gt; Select\n Sets an `AndWhere` or appends into an existing `AndWhere`.\n\n - If the outermost `Where` is an `AndWhere`, the new `Where` is appended\n   to the list within `AndWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `AndWhere`.\n\n NOTICE: `HAVING` allows to specify constraints much like `WHERE`, but\n filters the results after `GROUP BY` is applied instead of before. Because\n `HAVING` uses the same semantics as `WHERE`, it\n         takes a `Where`.\n\nSynonyms:\ncake/select.having\ncake/select having","url":"cake/select.html#having"},{"doc":"cake/select","title":"int","content":"pub fn int(value vl: Int) -&gt; SelectValue\n Creates an integer `Param` off an `Int`.\n\nSynonyms:\ncake/select.int\ncake/select int","url":"cake/select.html#int"},{"doc":"cake/select","title":"join","content":"pub fn join(query qry: Select, join jn: Join) -&gt; Select\n Adds a `Join` to the `Select` query.\n\nSynonyms:\ncake/select.join\ncake/select join","url":"cake/select.html#join"},{"doc":"cake/select","title":"joins","content":"pub fn joins(query qry: Select, joins jns: List(Join)) -&gt; Select\n Adds `Join`s to the `Select` query.\n\nSynonyms:\ncake/select.joins\ncake/select joins","url":"cake/select.html#joins"},{"doc":"cake/select","title":"limit","content":"pub fn limit(query qry: Select, limit lmt: Int) -&gt; Select\n Sets a `Limit` in the `Select` query.\n\nSynonyms:\ncake/select.limit\ncake/select limit","url":"cake/select.html#limit"},{"doc":"cake/select","title":"new","content":"pub fn new() -&gt; Select\n Creates an empty `Select` query.\n\nSynonyms:\ncake/select.new\ncake/select new","url":"cake/select.html#new"},{"doc":"cake/select","title":"no_comment","content":"pub fn no_comment(query qry: Select) -&gt; Select\n Removes the `Comment` from the `Select` query.\n\nSynonyms:\ncake/select.no_comment\ncake/select no_comment","url":"cake/select.html#no_comment"},{"doc":"cake/select","title":"no_epilog","content":"pub fn no_epilog(query qry: Select) -&gt; Select\n Removes the `Epilog` from the `Select` query.\n\nSynonyms:\ncake/select.no_epilog\ncake/select no_epilog","url":"cake/select.html#no_epilog"},{"doc":"cake/select","title":"no_from","content":"pub fn no_from(query qry: Select) -&gt; Select\n Removes the `FROM` clause of the `Select` query.\n\nSynonyms:\ncake/select.no_from\ncake/select no_from","url":"cake/select.html#no_from"},{"doc":"cake/select","title":"no_group_by","content":"pub fn no_group_by(query qry: Select) -&gt; Select\n Removes `GroupBy` from the `Select` query.\n\nSynonyms:\ncake/select.no_group_by\ncake/select no_group_by","url":"cake/select.html#no_group_by"},{"doc":"cake/select","title":"no_having","content":"pub fn no_having(query qry: Select) -&gt; Select\n Removes `HAVING` from the `Select` query.\n\nSynonyms:\ncake/select.no_having\ncake/select no_having","url":"cake/select.html#no_having"},{"doc":"cake/select","title":"no_join","content":"pub fn no_join(query qry: Select) -&gt; Select\n Removes any `Joins` from the `Select` query.\n\nSynonyms:\ncake/select.no_join\ncake/select no_join","url":"cake/select.html#no_join"},{"doc":"cake/select","title":"no_limit","content":"pub fn no_limit(query qry: Select) -&gt; Select\n Removes `Limit` from the `Select` query.\n\nSynonyms:\ncake/select.no_limit\ncake/select no_limit","url":"cake/select.html#no_limit"},{"doc":"cake/select","title":"no_offset","content":"pub fn no_offset(query qry: Select) -&gt; Select\n Removes `Offset` from the `Select` query.\n\nSynonyms:\ncake/select.no_offset\ncake/select no_offset","url":"cake/select.html#no_offset"},{"doc":"cake/select","title":"no_order_by","content":"pub fn no_order_by(query qry: Select) -&gt; Select\n Removes the `OrderBy` from the `Select` query.\n\nSynonyms:\ncake/select.no_order_by\ncake/select no_order_by","url":"cake/select.html#no_order_by"},{"doc":"cake/select","title":"no_where","content":"pub fn no_where(query qry: Select) -&gt; Select\n Removes the `Where` from the `Select` query.\n\nSynonyms:\ncake/select.no_where\ncake/select no_where","url":"cake/select.html#no_where"},{"doc":"cake/select","title":"offset","content":"pub fn offset(query qry: Select, offst offst: Int) -&gt; Select\n Sets an `Offset` in the `Select` query.\n\nSynonyms:\ncake/select.offset\ncake/select offset","url":"cake/select.html#offset"},{"doc":"cake/select","title":"or_having","content":"pub fn or_having(query qry: Select, having whr: Where) -&gt; Select\n Sets an `OrWhere` or appends into an existing `OrWhere`.\n\n - If the outermost `Where` is an `OrWhere`, the new `Where` is appended\n   to the list within `OrWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `OrWhere`.\n\n See function `having` on details why this takes a `Where`.\n\nSynonyms:\ncake/select.or_having\ncake/select or_having","url":"cake/select.html#or_having"},{"doc":"cake/select","title":"or_where","content":"pub fn or_where(query qry: Select, where whr: Where) -&gt; Select\n Sets an `OrWhere` or appends into an existing `OrWhere`.\n\n - If the outermost `Where` is an `OrWhere`, the new `Where` is appended\n   to the list within `OrWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `OrWhere`.\n\nSynonyms:\ncake/select.or_where\ncake/select or_where","url":"cake/select.html#or_where"},{"doc":"cake/select","title":"order_by","content":"pub fn order_by(\n  query qry: Select,\n  by ordb: String,\n  direction dir: Direction,\n) -&gt; Select\n Creates or appends an `OrderBy` a column with a direction.\n\n The direction can either `ASC` or `DESC`.\n\nSynonyms:\ncake/select.order_by\ncake/select order_by","url":"cake/select.html#order_by"},{"doc":"cake/select","title":"order_by_asc","content":"pub fn order_by_asc(query qry: Select, by ordb: String) -&gt; Select\n Creates or appends an ascending `OrderBy`.\n\nSynonyms:\ncake/select.order_by_asc\ncake/select order_by_asc","url":"cake/select.html#order_by_asc"},{"doc":"cake/select","title":"order_by_asc_nulls_first","content":"pub fn order_by_asc_nulls_first(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Creates or appends an ascending `OrderBy` with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/select.order_by_asc_nulls_first\ncake/select order_by_asc_nulls_first","url":"cake/select.html#order_by_asc_nulls_first"},{"doc":"cake/select","title":"order_by_asc_nulls_last","content":"pub fn order_by_asc_nulls_last(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Creates or appends an ascending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/select.order_by_asc_nulls_last\ncake/select order_by_asc_nulls_last","url":"cake/select.html#order_by_asc_nulls_last"},{"doc":"cake/select","title":"order_by_desc","content":"pub fn order_by_desc(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Creates or appends a descending `OrderBy`.\n\nSynonyms:\ncake/select.order_by_desc\ncake/select order_by_desc","url":"cake/select.html#order_by_desc"},{"doc":"cake/select","title":"order_by_desc_nulls_first","content":"pub fn order_by_desc_nulls_first(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Creates or appends a descending order with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/select.order_by_desc_nulls_first\ncake/select order_by_desc_nulls_first","url":"cake/select.html#order_by_desc_nulls_first"},{"doc":"cake/select","title":"order_by_desc_nulls_last","content":"pub fn order_by_desc_nulls_last(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Creates or appends a descending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/select.order_by_desc_nulls_last\ncake/select order_by_desc_nulls_last","url":"cake/select.html#order_by_desc_nulls_last"},{"doc":"cake/select","title":"replace_group_by","content":"pub fn replace_group_by(\n  query qry: Select,\n  group_by grpb: String,\n) -&gt; Select\n Replaces `GroupBy` with a single `GroupBy`.\n\nSynonyms:\ncake/select.replace_group_by\ncake/select replace_group_by","url":"cake/select.html#replace_group_by"},{"doc":"cake/select","title":"replace_group_bys","content":"pub fn replace_group_bys(\n  query qry: Select,\n  group_bys grpbs: List(String),\n) -&gt; Select\n Replaces `GroupBy` with a list of `GroupBy`s.\n\nSynonyms:\ncake/select.replace_group_bys\ncake/select replace_group_bys","url":"cake/select.html#replace_group_bys"},{"doc":"cake/select","title":"replace_having","content":"pub fn replace_having(\n  query qry: Select,\n  having whr: Where,\n) -&gt; Select\n Replaces `HAVING` in the `Select` query.\n\n See function `having` on details why this takes a `Where`.\n\nSynonyms:\ncake/select.replace_having\ncake/select replace_having","url":"cake/select.html#replace_having"},{"doc":"cake/select","title":"replace_join","content":"pub fn replace_join(query qry: Select, join jn: Join) -&gt; Select\n Replaces any `Join`s of the `Select` query with a signle `Join`.\n\nSynonyms:\ncake/select.replace_join\ncake/select replace_join","url":"cake/select.html#replace_join"},{"doc":"cake/select","title":"replace_joins","content":"pub fn replace_joins(\n  query qry: Select,\n  joins jns: List(Join),\n) -&gt; Select\n Replaces any `Join`s of the `Select` query with the given `Join`s.\n\nSynonyms:\ncake/select.replace_joins\ncake/select replace_joins","url":"cake/select.html#replace_joins"},{"doc":"cake/select","title":"replace_order_by","content":"pub fn replace_order_by(\n  query qry: Select,\n  by ordb: String,\n  direction dir: Direction,\n) -&gt; Select\n Replaces the `OrderBy` a column with a direction.\n\nSynonyms:\ncake/select.replace_order_by\ncake/select replace_order_by","url":"cake/select.html#replace_order_by"},{"doc":"cake/select","title":"replace_order_by_asc","content":"pub fn replace_order_by_asc(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single ascending `OrderBy`.\n\nSynonyms:\ncake/select.replace_order_by_asc\ncake/select replace_order_by_asc","url":"cake/select.html#replace_order_by_asc"},{"doc":"cake/select","title":"replace_order_by_asc_nulls_first","content":"pub fn replace_order_by_asc_nulls_first(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single ascending `OrderBy` with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/select.replace_order_by_asc_nulls_first\ncake/select replace_order_by_asc_nulls_first","url":"cake/select.html#replace_order_by_asc_nulls_first"},{"doc":"cake/select","title":"replace_order_by_asc_nulls_last","content":"pub fn replace_order_by_asc_nulls_last(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single ascending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/select.replace_order_by_asc_nulls_last\ncake/select replace_order_by_asc_nulls_last","url":"cake/select.html#replace_order_by_asc_nulls_last"},{"doc":"cake/select","title":"replace_order_by_desc","content":"pub fn replace_order_by_desc(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single descending order.\n\nSynonyms:\ncake/select.replace_order_by_desc\ncake/select replace_order_by_desc","url":"cake/select.html#replace_order_by_desc"},{"doc":"cake/select","title":"replace_order_by_desc_nulls_first","content":"pub fn replace_order_by_desc_nulls_first(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single descending order with `NULLS FIRST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS FIRST` out of the box.\n\nSynonyms:\ncake/select.replace_order_by_desc_nulls_first\ncake/select replace_order_by_desc_nulls_first","url":"cake/select.html#replace_order_by_desc_nulls_first"},{"doc":"cake/select","title":"replace_order_by_desc_nulls_last","content":"pub fn replace_order_by_desc_nulls_last(\n  query qry: Select,\n  by ordb: String,\n) -&gt; Select\n Replaces the `OrderBy` a single descending `OrderBy` with `NULLS LAST`.\n\n NOTICE: MariaDB/MySQL do not support `NULLS LAST` out of the box.\n\nSynonyms:\ncake/select.replace_order_by_desc_nulls_last\ncake/select replace_order_by_desc_nulls_last","url":"cake/select.html#replace_order_by_desc_nulls_last"},{"doc":"cake/select","title":"replace_select","content":"pub fn replace_select(\n  query qry: Select,\n  select_value sv: SelectValue,\n) -&gt; Select\n Add a `SelectValue`s to the `Select` query.\n\n If the query already has any `SelectValue`s, they are replaced.\n\nSynonyms:\ncake/select.replace_select\ncake/select replace_select","url":"cake/select.html#replace_select"},{"doc":"cake/select","title":"replace_selects","content":"pub fn replace_selects(\n  query qry: Select,\n  select_values svs: List(SelectValue),\n) -&gt; Select\n Adds `SelectValue`s to the `Select` query.\n\n If the query already has any `SelectValue`s, they are replaced.\n\nSynonyms:\ncake/select.replace_selects\ncake/select replace_selects","url":"cake/select.html#replace_selects"},{"doc":"cake/select","title":"replace_where","content":"pub fn replace_where(\n  query qry: Select,\n  where whr: Where,\n) -&gt; Select\n Replaces the `Where` in the `Select` query.\n\nSynonyms:\ncake/select.replace_where\ncake/select replace_where","url":"cake/select.html#replace_where"},{"doc":"cake/select","title":"select","content":"pub fn select(\n  query qry: Select,\n  select_value sv: SelectValue,\n) -&gt; Select\n Add a `SelectValue` to the `Select` query.\n\n If the query already has any `SelectValue`s, the new one is appended.\n\nSynonyms:\ncake/select.select\ncake/select select","url":"cake/select.html#select"},{"doc":"cake/select","title":"selects","content":"pub fn selects(\n  query qry: Select,\n  select_values svs: List(SelectValue),\n) -&gt; Select\n Adds `SelectValue`s to the `Select` query.\n\n If the query already has any `SelectValue`s, the new ones are appended.\n\nSynonyms:\ncake/select.selects\ncake/select selects","url":"cake/select.html#selects"},{"doc":"cake/select","title":"string","content":"pub fn string(value vl: String) -&gt; SelectValue\n Creates a string `Param` off a `String`.\n\nSynonyms:\ncake/select.string\ncake/select string","url":"cake/select.html#string"},{"doc":"cake/select","title":"to_query","content":"pub fn to_query(query qry: Select) -&gt; Query\n Creates a `Query` from a `Select` query.\n\nSynonyms:\ncake/select.to_query\ncake/select to_query","url":"cake/select.html#to_query"},{"doc":"cake/select","title":"where","content":"pub fn where(query qry: Select, where whr: Where) -&gt; Select\n Sets an `AndWhere` or appends into an existing `AndWhere`.\n\n - If the outermost `Where` is an `AndWhere`, the new `Where` is appended\n   to the list within `AndWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `AndWhere`.\n\nSynonyms:\ncake/select.where\ncake/select where","url":"cake/select.html#where"},{"doc":"cake/select","title":"xor_having","content":"pub fn xor_having(query qry: Select, having whr: Where) -&gt; Select\n Sets an `XorWhere` or appends into an existing `XorWhere`.\n\n - If the outermost `Where` is an `XorWhere`, the new `Where` is appended\n   to the list within `XorWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `XorWhere`.\n\n See function `having` on details why this takes a `Where`.\n\n NOTICE: This operator does not exist in Postgres or SQLite,\n and *Cake* generates equivalent SQL using `OR` and `AND` and `NOT`.\n This operator exists in MariaDB/MySQL.\n\nSynonyms:\ncake/select.xor_having\ncake/select xor_having","url":"cake/select.html#xor_having"},{"doc":"cake/select","title":"xor_where","content":"pub fn xor_where(query qry: Select, where whr: Where) -&gt; Select\n Sets an `XorWhere` or appends into an existing `XorWhere`.\n\n - If the outermost `Where` is an `XorWhere`, the new `Where` is appended\n   to the list within `XorWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `XorWhere`.\n\n NOTICE: This operator does not exist in Postgres or SQLite,\n and *Cake* generates equivalent SQL using `OR` and `AND` and `NOT`.\n This operator exists in MariaDB/MySQL.\n\nSynonyms:\ncake/select.xor_where\ncake/select xor_where","url":"cake/select.html#xor_where"},{"doc":"cake/select","title":"cake/select","content":" A DSL to build `SELECT` queries.\n","url":"cake/select.html"},{"doc":"cake/update","title":"bool","content":"pub fn bool(value vl: Bool) -&gt; Param\n Creates a `Param` from a `Bool`.\n\nSynonyms:\ncake/update.bool\ncake/update bool","url":"cake/update.html#bool"},{"doc":"cake/update","title":"comment","content":"pub fn comment(\n  query qry: Update(a),\n  comment cmmnt: String,\n) -&gt; Update(a)\n Sets a `Comment` or appends into an existing `Comment`.\n\nSynonyms:\ncake/update.comment\ncake/update comment","url":"cake/update.html#comment"},{"doc":"cake/update","title":"epilog","content":"pub fn epilog(\n  query qry: Update(a),\n  epilog eplg: String,\n) -&gt; Update(a)\n Sets an `Epilog` or appends into an existing `Epilog`.\n\nSynonyms:\ncake/update.epilog\ncake/update epilog","url":"cake/update.html#epilog"},{"doc":"cake/update","title":"float","content":"pub fn float(value vl: Float) -&gt; Param\n Creates a `Param` from a `Float`.\n\nSynonyms:\ncake/update.float\ncake/update float","url":"cake/update.html#float"},{"doc":"cake/update","title":"from_sub_query","content":"pub fn from_sub_query(\n  query qry: Update(a),\n  sub_query sb_qry: Query,\n  alias als: String,\n) -&gt; Update(a)\n Sets the `FROM` clause of the `Update` query to an aliased sub-query.\n\nSynonyms:\ncake/update.from_sub_query\ncake/update from_sub_query","url":"cake/update.html#from_sub_query"},{"doc":"cake/update","title":"from_table","content":"pub fn from_table(\n  query qry: Update(a),\n  name tbl_nm: String,\n) -&gt; Update(a)\n Sets the `FROM` clause of the `Update` query to a table name.\n\nSynonyms:\ncake/update.from_table\ncake/update from_table","url":"cake/update.html#from_table"},{"doc":"cake/update","title":"get_comment","content":"pub fn get_comment(query qry: Update(a)) -&gt; Comment\n Gets the `Comment` of the `Update` query.\n\nSynonyms:\ncake/update.get_comment\ncake/update get_comment","url":"cake/update.html#get_comment"},{"doc":"cake/update","title":"get_epilog","content":"pub fn get_epilog(query qry: Update(a)) -&gt; Epilog\n Gets the `Epilog` of the `Update` query.\n\nSynonyms:\ncake/update.get_epilog\ncake/update get_epilog","url":"cake/update.html#get_epilog"},{"doc":"cake/update","title":"get_from","content":"pub fn get_from(query qry: Update(a)) -&gt; From\n Gets the `FROM` clause of the `Update` query.\n\nSynonyms:\ncake/update.get_from\ncake/update get_from","url":"cake/update.html#get_from"},{"doc":"cake/update","title":"get_joins","content":"pub fn get_joins(query qry: Update(a)) -&gt; Joins\n Gets the `Joins` of the `Update` query.\n\nSynonyms:\ncake/update.get_joins\ncake/update get_joins","url":"cake/update.html#get_joins"},{"doc":"cake/update","title":"get_set","content":"pub fn get_set(query qry: Update(a)) -&gt; List(UpdateSet)\n Get the sets of the `Update` query.\n\nSynonyms:\ncake/update.get_set\ncake/update get_set","url":"cake/update.html#get_set"},{"doc":"cake/update","title":"get_table","content":"pub fn get_table(query qry: Update(a)) -&gt; UpdateTable\n Get the table of the `Update` query.\n\nSynonyms:\ncake/update.get_table\ncake/update get_table","url":"cake/update.html#get_table"},{"doc":"cake/update","title":"get_where","content":"pub fn get_where(query qry: Update(a)) -&gt; Where\n Gets the `Where` of the `Update` query.\n\nSynonyms:\ncake/update.get_where\ncake/update get_where","url":"cake/update.html#get_where"},{"doc":"cake/update","title":"int","content":"pub fn int(value vl: Int) -&gt; Param\n Creates a `Param` from an `Int`.\n\nSynonyms:\ncake/update.int\ncake/update int","url":"cake/update.html#int"},{"doc":"cake/update","title":"join","content":"pub fn join(query qry: Update(a), join jn: Join) -&gt; Update(a)\n Adds a `Join` to the `Update` query.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/update.join\ncake/update join","url":"cake/update.html#join"},{"doc":"cake/update","title":"joins","content":"pub fn joins(\n  query qry: Update(a),\n  joins jns: List(Join),\n) -&gt; Update(a)\n Adds `Join`s to the `Update` query.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/update.joins\ncake/update joins","url":"cake/update.html#joins"},{"doc":"cake/update","title":"new","content":"pub fn new() -&gt; Update(a)\n Creates an empty `Update` query.\n\nSynonyms:\ncake/update.new\ncake/update new","url":"cake/update.html#new"},{"doc":"cake/update","title":"no_comment","content":"pub fn no_comment(query qry: Update(a)) -&gt; Update(a)\n Removes the `Comment` from the `Update` query.\n\nSynonyms:\ncake/update.no_comment\ncake/update no_comment","url":"cake/update.html#no_comment"},{"doc":"cake/update","title":"no_epilog","content":"pub fn no_epilog(query qry: Update(a)) -&gt; Update(a)\n Removes the `Epilog` from the `Update` query.\n\nSynonyms:\ncake/update.no_epilog\ncake/update no_epilog","url":"cake/update.html#no_epilog"},{"doc":"cake/update","title":"no_from","content":"pub fn no_from(query qry: Update(a)) -&gt; Update(a)\n Removes the `FROM` clause of the `Update` query.\n\nSynonyms:\ncake/update.no_from\ncake/update no_from","url":"cake/update.html#no_from"},{"doc":"cake/update","title":"no_join","content":"pub fn no_join(query qry: Update(a)) -&gt; Update(a)\n Removes any `Joins` from the `Update` query.\n\nSynonyms:\ncake/update.no_join\ncake/update no_join","url":"cake/update.html#no_join"},{"doc":"cake/update","title":"no_returning","content":"pub fn no_returning(query qry: Update(a)) -&gt; Update(a)\n NOTICE: MariaDB/MySQL do not support `RETURNING` in `UPDATE` queries;\n they do support it in `INSERT` (and `REPLACE`) queries, however.\n\nSynonyms:\ncake/update.no_returning\ncake/update no_returning","url":"cake/update.html#no_returning"},{"doc":"cake/update","title":"no_where","content":"pub fn no_where(query qry: Update(a)) -&gt; Update(a)\n Removes the `Where` from the `Update` query.\n\nSynonyms:\ncake/update.no_where\ncake/update no_where","url":"cake/update.html#no_where"},{"doc":"cake/update","title":"or_where","content":"pub fn or_where(\n  query qry: Update(a),\n  where whr: Where,\n) -&gt; Update(a)\n Sets an `OrWhere` or appends into an existing `OrWhere`.\n\n - If the outermost `Where` is an `OrWhere`, the new `Where` is appended\n   to the list within `OrWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `OrWhere`.\n\nSynonyms:\ncake/update.or_where\ncake/update or_where","url":"cake/update.html#or_where"},{"doc":"cake/update","title":"replace_join","content":"pub fn replace_join(\n  query qry: Update(a),\n  join jn: Join,\n) -&gt; Update(a)\n Replaces any `Join`s of the `Update` query with a signle `Join`.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/update.replace_join\ncake/update replace_join","url":"cake/update.html#replace_join"},{"doc":"cake/update","title":"replace_joins","content":"pub fn replace_joins(\n  query qry: Update(a),\n  joins jns: List(Join),\n) -&gt; Update(a)\n Replaces any `Join`s of the `Update` query with the given `Join`s.\n\n NOTICE: On Postgres/SQLite `Joins` are only allowed if the `FROM` clause is\n set as well.\n\nSynonyms:\ncake/update.replace_joins\ncake/update replace_joins","url":"cake/update.html#replace_joins"},{"doc":"cake/update","title":"replace_where","content":"pub fn replace_where(\n  query qry: Update(a),\n  where whr: Where,\n) -&gt; Update(a)\n Replaces the `Where` in the `Update` query.\n\nSynonyms:\ncake/update.replace_where\ncake/update replace_where","url":"cake/update.html#replace_where"},{"doc":"cake/update","title":"returning","content":"pub fn returning(\n  query qry: Update(a),\n  returning rtrn: List(String),\n) -&gt; Update(a)\n NOTICE: MariaDB/MySQL do not support `RETURNING` in `UPDATE` queries;\n they do support it in `INSERT` (and `REPLACE`) queries, however.\n\nSynonyms:\ncake/update.returning\ncake/update returning","url":"cake/update.html#returning"},{"doc":"cake/update","title":"set","content":"pub fn set(query qry: Update(a), set st: UpdateSet) -&gt; Update(a)\n Sets or appends one columne set in an `Update` query.\n\nSynonyms:\ncake/update.set\ncake/update set","url":"cake/update.html#set"},{"doc":"cake/update","title":"set_many_to_expression","content":"pub fn set_many_to_expression(\n  columns cols: List(String),\n  expression exp: String,\n) -&gt; UpdateSet\n Sets many columns to an expression value.\n\n NOTICE: the expression must return an equal count of columns.\n\nSynonyms:\ncake/update.set_many_to_expression\ncake/update set_many_to_expression","url":"cake/update.html#set_many_to_expression"},{"doc":"cake/update","title":"set_many_to_sub_query","content":"pub fn set_many_to_sub_query(\n  columns cols: List(String),\n  sub_query qry: Query,\n) -&gt; UpdateSet\n Sets many columns to a sub-query value.\n\n NOTICE: the sub-query must return an equal count of columns.\n\nSynonyms:\ncake/update.set_many_to_sub_query\ncake/update set_many_to_sub_query","url":"cake/update.html#set_many_to_sub_query"},{"doc":"cake/update","title":"set_replace","content":"pub fn set_replace(\n  query qry: Update(a),\n  set st: UpdateSet,\n) -&gt; Update(a)\n Sets or replaces one column set in an `Update` query.\n\nSynonyms:\ncake/update.set_replace\ncake/update set_replace","url":"cake/update.html#set_replace"},{"doc":"cake/update","title":"set_to_expression","content":"pub fn set_to_expression(\n  column col: String,\n  expression exp: String,\n) -&gt; UpdateSet\n Sets a column to an expression value.\n\nSynonyms:\ncake/update.set_to_expression\ncake/update set_to_expression","url":"cake/update.html#set_to_expression"},{"doc":"cake/update","title":"set_to_param","content":"pub fn set_to_param(\n  column col: String,\n  param prm: Param,\n) -&gt; UpdateSet\n Sets a column to a param value.\n\nSynonyms:\ncake/update.set_to_param\ncake/update set_to_param","url":"cake/update.html#set_to_param"},{"doc":"cake/update","title":"set_to_sub_query","content":"pub fn set_to_sub_query(\n  column col: String,\n  sub_query qry: Query,\n) -&gt; UpdateSet\n Sets a column to a sub-query value.\n\nSynonyms:\ncake/update.set_to_sub_query\ncake/update set_to_sub_query","url":"cake/update.html#set_to_sub_query"},{"doc":"cake/update","title":"sets","content":"pub fn sets(\n  query qry: Update(a),\n  set sts: List(UpdateSet),\n) -&gt; Update(a)\n Sets or appends many column sets n an `Update` query.\n\nSynonyms:\ncake/update.sets\ncake/update sets","url":"cake/update.html#sets"},{"doc":"cake/update","title":"sets_replace","content":"pub fn sets_replace(\n  query qry: Update(a),\n  sets sts: List(UpdateSet),\n) -&gt; Update(a)\n Sets or replaces many column sets in an `Update` query.\n\nSynonyms:\ncake/update.sets_replace\ncake/update sets_replace","url":"cake/update.html#sets_replace"},{"doc":"cake/update","title":"string","content":"pub fn string(value vl: String) -&gt; Param\n Creates a `Param` from a `String`.\n\nSynonyms:\ncake/update.string\ncake/update string","url":"cake/update.html#string"},{"doc":"cake/update","title":"table","content":"pub fn table(\n  query qry: Update(a),\n  table_name tbl_nm: String,\n) -&gt; Update(a)\n Sets the table of the `Update` query.\n\nSynonyms:\ncake/update.table\ncake/update table","url":"cake/update.html#table"},{"doc":"cake/update","title":"to_query","content":"pub fn to_query(update updt: Update(a)) -&gt; WriteQuery(a)\n Creates a `WriteQuery` from an `Update` query.\n\nSynonyms:\ncake/update.to_query\ncake/update to_query","url":"cake/update.html#to_query"},{"doc":"cake/update","title":"where","content":"pub fn where(query qry: Update(a), where whr: Where) -&gt; Update(a)\n Sets an `AndWhere` or appends into an existing `AndWhere`.\n\n - If the outermost `Where` is an `AndWhere`, the new `Where` is appended\n   to the list within `AndWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `AndWhere`.\n\nSynonyms:\ncake/update.where\ncake/update where","url":"cake/update.html#where"},{"doc":"cake/update","title":"xor_where","content":"pub fn xor_where(\n  query qry: Update(a),\n  where whr: Where,\n) -&gt; Update(a)\n Sets an `XorWhere` or appends into an existing `XorWhere`.\n\n - If the outermost `Where` is an `XorWhere`, the new `Where` is appended\n   to the list within `XorWhere`.\n - If the query does not have a `Where` clause, the given `Where` is set\n   instead.\n - If the outermost `Where` is any other kind of `Where`, this and the\n   current outermost `Where` are wrapped in an `XorWhere`.\n\n NOTICE: This operator does not exist in Postgres or SQLite,\n and *Cake* generates equivalent SQL using `OR` and `AND` and `NOT`.\n This operator exists in MariaDB/MySQL.\n\nSynonyms:\ncake/update.xor_where\ncake/update xor_where","url":"cake/update.html#xor_where"},{"doc":"cake/update","title":"cake/update","content":" A DSL to build `UPDATE` queries.\n","url":"cake/update.html"},{"doc":"cake/where","title":"and","content":"pub fn and(wheres whrs: List(Where)) -&gt; Where\n Logical AND of multiple `Where`s.\n\nSynonyms:\ncake/where.and\ncake/where and","url":"cake/where.html#and"},{"doc":"cake/where","title":"between","content":"pub fn between(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n  value_c vl_c: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` A is between two\n `WhereValue`s B and C.\n\nSynonyms:\ncake/where.between\ncake/where between","url":"cake/where.html#between"},{"doc":"cake/where","title":"col","content":"pub fn col(name: String) -&gt; WhereValue\n Creates a `WhereValue` from a column name `String`.\n\nSynonyms:\ncake/where.col\ncake/where col","url":"cake/where.html#col"},{"doc":"cake/where","title":"eq","content":"pub fn eq(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` equals another\n `WhereValue`.\n\nSynonyms:\ncake/where.eq\ncake/where eq","url":"cake/where.html#eq"},{"doc":"cake/where","title":"eq_all_query","content":"pub fn eq_all_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` matches all\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.eq_all_query\ncake/where eq_all_query","url":"cake/where.html#eq_all_query"},{"doc":"cake/where","title":"eq_any_query","content":"pub fn eq_any_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` matches any\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.eq_any_query\ncake/where eq_any_query","url":"cake/where.html#eq_any_query"},{"doc":"cake/where","title":"exists_in_query","content":"pub fn exists_in_query(sub_query qry: Query) -&gt; Where\n Creates a `WHERE` clause that checks if it exists in a sub-query.\n\nSynonyms:\ncake/where.exists_in_query\ncake/where exists_in_query","url":"cake/where.html#exists_in_query"},{"doc":"cake/where","title":"float","content":"pub fn float(v vl: Float) -&gt; WhereValue\n Creates a `WhereValue` from a `Float`.\n\nSynonyms:\ncake/where.float\ncake/where float","url":"cake/where.html#float"},{"doc":"cake/where","title":"fragment","content":"pub fn fragment(fragment frgmt: Fragment) -&gt; Where\n Creates a `WhereFragment` from a `Fragment`.\n\nSynonyms:\ncake/where.fragment\ncake/where fragment","url":"cake/where.html#fragment"},{"doc":"cake/where","title":"fragment_value","content":"pub fn fragment_value(fragment frgmt: Fragment) -&gt; WhereValue\n Creates a `WhereValue` from a `Fragment`.\n\nSynonyms:\ncake/where.fragment_value\ncake/where fragment_value","url":"cake/where.html#fragment_value"},{"doc":"cake/where","title":"gt","content":"pub fn gt(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater than\n another `WhereValue`.\n\nSynonyms:\ncake/where.gt\ncake/where gt","url":"cake/where.html#gt"},{"doc":"cake/where","title":"gt_all_query","content":"pub fn gt_all_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater than all\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.gt_all_query\ncake/where gt_all_query","url":"cake/where.html#gt_all_query"},{"doc":"cake/where","title":"gt_any_query","content":"pub fn gt_any_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater than any\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.gt_any_query\ncake/where gt_any_query","url":"cake/where.html#gt_any_query"},{"doc":"cake/where","title":"gte","content":"pub fn gte(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater or equal\n to another `WhereValue`.\n\nSynonyms:\ncake/where.gte\ncake/where gte","url":"cake/where.html#gte"},{"doc":"cake/where","title":"gte_all_query","content":"pub fn gte_all_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater or equal\n to all in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.gte_all_query\ncake/where gte_all_query","url":"cake/where.html#gte_all_query"},{"doc":"cake/where","title":"gte_any_query","content":"pub fn gte_any_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is greater or equal to\n any in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.gte_any_query\ncake/where gte_any_query","url":"cake/where.html#gte_any_query"},{"doc":"cake/where","title":"ilike","content":"pub fn ilike(\n  value vl: WhereValue,\n  pattern pttrn: String,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` matches a pattern.\n\n `ilike` is the same as `like` but case-insensitive.\n\nSynonyms:\ncake/where.ilike\ncake/where ilike","url":"cake/where.html#ilike"},{"doc":"cake/where","title":"in","content":"pub fn in(\n  value vl: WhereValue,\n  values vals: List(WhereValue),\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is in a list of\n `WhereValue`s.\n\nSynonyms:\ncake/where.in\ncake/where in","url":"cake/where.html#in"},{"doc":"cake/where","title":"int","content":"pub fn int(v vl: Int) -&gt; WhereValue\n Creates a `WhereValue` from an `Int`.\n\nSynonyms:\ncake/where.int\ncake/where int","url":"cake/where.html#int"},{"doc":"cake/where","title":"is_bool","content":"pub fn is_bool(value vl: WhereValue, bool b: Bool) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` matches a `Bool`.\nSynonyms:\ncake/where.is_bool\ncake/where is_bool","url":"cake/where.html#is_bool"},{"doc":"cake/where","title":"is_false","content":"pub fn is_false(value vl: WhereValue) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is `False`.\nSynonyms:\ncake/where.is_false\ncake/where is_false","url":"cake/where.html#is_false"},{"doc":"cake/where","title":"is_not_bool","content":"pub fn is_not_bool(value vl: WhereValue, bool b: Bool) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` does not match a `Bool`.\nSynonyms:\ncake/where.is_not_bool\ncake/where is_not_bool","url":"cake/where.html#is_not_bool"},{"doc":"cake/where","title":"is_not_null","content":"pub fn is_not_null(value vl: WhereValue) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is not SQL `NULL`.\n\nSynonyms:\ncake/where.is_not_null\ncake/where is_not_null","url":"cake/where.html#is_not_null"},{"doc":"cake/where","title":"is_null","content":"pub fn is_null(value vl: WhereValue) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is SQL `NULL`.\n\nSynonyms:\ncake/where.is_null\ncake/where is_null","url":"cake/where.html#is_null"},{"doc":"cake/where","title":"is_true","content":"pub fn is_true(value vl: WhereValue) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is `True`.\nSynonyms:\ncake/where.is_true\ncake/where is_true","url":"cake/where.html#is_true"},{"doc":"cake/where","title":"like","content":"pub fn like(value vl: WhereValue, pattern pttrn: String) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` matches a pattern.\n The pattern can contain for example the following wildcards:\n\n - `%` matches any sequence of characters.\n - `_` matches any single character.\n\nSynonyms:\ncake/where.like\ncake/where like","url":"cake/where.html#like"},{"doc":"cake/where","title":"lt","content":"pub fn lt(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` lower than another\n `WhereValue`.\n\nSynonyms:\ncake/where.lt\ncake/where lt","url":"cake/where.html#lt"},{"doc":"cake/where","title":"lt_all_query","content":"pub fn lt_all_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is lower than all\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.lt_all_query\ncake/where lt_all_query","url":"cake/where.html#lt_all_query"},{"doc":"cake/where","title":"lt_any_query","content":"pub fn lt_any_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is lower than an any\n in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.lt_any_query\ncake/where lt_any_query","url":"cake/where.html#lt_any_query"},{"doc":"cake/where","title":"lte","content":"pub fn lte(\n  value_a vl_a: WhereValue,\n  value_b vl_b: WhereValue,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` lower or equal to\n another `WhereValue`.\n\nSynonyms:\ncake/where.lte\ncake/where lte","url":"cake/where.html#lte"},{"doc":"cake/where","title":"lte_all_query","content":"pub fn lte_all_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is lower or equal to\n all in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.lte_all_query\ncake/where lte_all_query","url":"cake/where.html#lte_all_query"},{"doc":"cake/where","title":"lte_any_query","content":"pub fn lte_any_query(\n  value vl: WhereValue,\n  sub_query qry: Query,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is lower or equal to\n any in a sub-query.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.lte_any_query\ncake/where lte_any_query","url":"cake/where.html#lte_any_query"},{"doc":"cake/where","title":"not","content":"pub fn not(where whr: Where) -&gt; Where\n Negates a `Where`.\n\nSynonyms:\ncake/where.not\ncake/where not","url":"cake/where.html#not"},{"doc":"cake/where","title":"null","content":"pub fn null() -&gt; WhereValue\n Creates a `NULL` `WhereValue`.\n\nSynonyms:\ncake/where.null\ncake/where null","url":"cake/where.html#null"},{"doc":"cake/where","title":"or","content":"pub fn or(wheres whrs: List(Where)) -&gt; Where\n Logical OR of multiple `Where`s.\n\nSynonyms:\ncake/where.or\ncake/where or","url":"cake/where.html#or"},{"doc":"cake/where","title":"similar_to","content":"pub fn similar_to(\n  value vl: WhereValue,\n  to pttrn: String,\n) -&gt; Where\n Creates a `WHERE` clause that checks if a `WhereValue` is similar to a\n pattern.\n\n NOTICE: Not supported by SQLite.\n\nSynonyms:\ncake/where.similar_to\ncake/where similar_to","url":"cake/where.html#similar_to"},{"doc":"cake/where","title":"string","content":"pub fn string(v vl: String) -&gt; WhereValue\n Creates a `WhereValue` from a `String`.\n\nSynonyms:\ncake/where.string\ncake/where string","url":"cake/where.html#string"},{"doc":"cake/where","title":"xor","content":"pub fn xor(wheres whrs: List(Where)) -&gt; Where\n Logical XOR of multiple `Where`s.\n\nSynonyms:\ncake/where.xor\ncake/where xor","url":"cake/where.html#xor"},{"doc":"cake/where","title":"cake/where","content":" Used to build `WHERE` clauses for SQL queries.\n\n Where clauses are used to filter rows in a table.\n\n Also used to build `HAVING` clauses for SQL queries, because they work the\n same way as `WHERE` clauses, but are used to filter rows after `GROUP BY`\n has been applied.\n\n ## Compatibility\n\n - SQLite does not support `ANY`, `ALL` and `SIMILAR TO`.\n","url":"cake/where.html"}]);